@@ -2,4 +2,8 @@
 from .config import (add_args, Config, ConfigDict, DictAction,
                      merge_cfg_and_args)
 
+from .logging import (get_logger, print_log, get_log_dir, collect_logger)
+
+from .backup import backup
+
 __all__ = [k for k in globals().keys() if not k.startswith("_")]
